==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_en.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Work</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Life</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Other</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Close</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>One day before start</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Remind me tomorrow</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Remind me later</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 mins later</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 hour later</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 hours later</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Tomorrow</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Schedule Reminder</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 to %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Today</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">One day before start</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Close</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Remind me tomorrow</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Remind me later</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Schedule Reminder</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 to %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Today</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Tomorrow</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_en.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Work</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Life</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Other</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Close</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>One day before start</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Remind me tomorrow</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Remind me later</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 mins later</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 hour later</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 hours later</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Tomorrow</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Schedule Reminder</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 to %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Today</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
